aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorTakashi Sakamoto <o-takashi@sakamocchi.jp>2023-08-11 18:26:22 +0900
committerTakashi Sakamoto <o-takashi@sakamocchi.jp>2023-10-07 11:42:33 +0900
commit614d4fe9130a9484e9bfdda1555b9b07cde72e7d (patch)
tree4fbd3a29419828a5df61a72a78527215968fb3d4
parenta86d7e379573ae2fa114cc94c1061480811cbca6 (diff)
downloadlibhinawa-614d4fe9130a9484e9bfdda1555b9b07cde72e7d.tar.gz
fw_resp: rename name of some arguments related to node-id and card index
Both src and dst arguments of requested signal express node-id in IEEE 1394 bus. The card argument expresses the index of 1394 OHCI hardware available in Linux system. For readability, this commit adds '_node_id' and '_id' suffixes to them. Signed-off-by: Takashi Sakamoto <o-takashi@sakamocchi.jp>
-rw-r--r--src/fw_resp.c7
-rw-r--r--src/fw_resp.h12
2 files changed, 11 insertions, 8 deletions
diff --git a/src/fw_resp.c b/src/fw_resp.c
index 137c78f..6c4b318 100644
--- a/src/fw_resp.c
+++ b/src/fw_resp.c
@@ -158,9 +158,10 @@ static void hinawa_fw_resp_class_init(HinawaFwRespClass *klass)
* @self: A [class@FwResp]
* @tcode: One of [enum@FwTcode] enumerations
* @offset: The address offset at which the transaction arrives.
- * @src: The node ID of source for the transaction.
- * @dst: The node ID of destination for the transaction.
- * @card: The index of card corresponding to 1394 OHCI controller.
+ * @src_node_id: The node ID of source for the transaction.
+ * @dst_node_id: The node ID of destination for the transaction.
+ * @card_id: The index of card specific to the 1394 OHCI controller at which the request
+ * subaction arrived.
* @generation: The generation of bus when the transaction is transferred.
* @tstamp: The isochronous cycle at which the request arrived.
* @frame: (element-type guint8)(array length=length): The array with elements for byte
diff --git a/src/fw_resp.h b/src/fw_resp.h
index 2f1c1b1..c698ac0 100644
--- a/src/fw_resp.h
+++ b/src/fw_resp.h
@@ -22,9 +22,10 @@ struct _HinawaFwRespClass {
* @self: A [class@FwResp]
* @tcode: One of [enum@FwTcode] enumerations
* @offset: The address offset at which the transaction arrives.
* @src: The node ID of source for the transaction.
* @dst: The node ID of destination for the transaction.
* @card: The index of card corresponding to 1394 OHCI controller.
* @generation: The generation of bus when the transaction is transferred.
* @tstamp: The time stamp at which the request arrived.
* @frame: (element-type guint8)(array length=length): The array with elements for byte
@@ -39,8 +40,9 @@ struct _HinawaFwRespClass {
* Since: 3.0
*/
HinawaFwRcode (*requested)(HinawaFwResp *self, HinawaFwTcode tcode, guint64 offset,
- guint src, guint dst, guint card, guint generation,
- guint tstamp, const guint8 *frame, guint length);
+ guint src_node_id, guint dst_node_id, guint card_id,
+ guint generation, guint tstamp,
+ const guint8 *frame, guint length);
};
HinawaFwResp *hinawa_fw_resp_new(void);
@@ -22,9 +22,10 @@ struct _HinawaFwRespClass {
* @tcode: One of [enum@FwTcode] enumerations
* @offset: The address offset at which the transaction arrives.
- * @src: The node ID of source for the transaction.
- * @dst: The node ID of destination for the transaction.
- * @card: The index of card corresponding to 1394 OHCI controller.
+ * @src_node_id: The node ID of source for the transaction.
+ * @dst_node_id: The node ID of destination for the transaction.
+ * @card_id: The index of card specific to 1394 OHCI controller at which the request
+ * subaction arrived.
* @generation: The generation of bus when the transaction is transferred.
* @tstamp: The time stamp at which the request arrived.